==> ngx-bootstrap-expanded-features-1.0.5.tgz: package/README.md <==
# NgxBootstrapExpandedFeatures

## 📝 Table of Contents

- [About](#about)
- [The problem](#problem)
- [The Solution](#solution)
- [Getting Started](#getting_started)
- [More Information](#more_info)
- [Authors](#authors)

## 🧐 IMPORTANT: BREAKING CHANGES, READ BEFORE UPDATE:</a>
The border changed to borderWidth and bw, please change that in your code to have border well written.

## 🧐 About <a name = “about”></a>

Too many new features for bootstrap made with javascript for better performance and more options without a large css file.

## 😭 The problem <a name = “problem”></a>

Bootstrap doesn't support options of their classes like w-33 to have width: 33%; on an element or things more especific like h-20vh to have an element with: height 20vh;, that can be more efficient and responsive and whenever we need those, we need to get it though a css style sheet and thats not the main point of using Bootstrap.

First I tried to make a library for sass to get to many more options for the classes but there was one problem, it was an 50mb size file after beeing compiled, and we know that 50mb its a large file to be downloaded only to use a few classes that are on the file, but then I get one idea that can let anybody to get all the css that they want without having all the options that they dont use and having the option to create more colors that can be used with bg-newcolorname to get background-color: newcolor; and many more options.

## 😎 The solution <a name = “solution”></a>
We can now use this js library that creates all the css with the classes that are like in bootstrap just in the load of your pages, that mean that your users will only need to download the js and not a css file of 50mb+ and speed up you charge with a simple task that only consumes a few memory of the ram of the user.

## 🏁 Getting Started <a name = “about”></a>

You can check the full tutorial on this [link](https://bootstrap-expanded-features.vercel.app/)

## ⛏️ More Information <a name = “more_info”></a>

We get the idea of how to use the colors from the sass of bootstrap, more specific, from the _variables.scss file on the source files.

- [How to create a new CSS Rule on an empty css style sheet](https://stackoverflow.com/questions/6620393/is-it-possible-to-alter-a-css-stylesheet-using-javascript-not-the-style-of-an)
- [How to convert HEX to rgb and viceversa](https://stackoverflow.com/questions/5560248/programmatically-lighten-or-darken-a-hex-color-or-rgb-and-blend-colors)
- [How to shadeTintColor](https://stackoverflow.com/questions/5560248/programmatically-lighten-or-darken-a-hex-color-or-rgb-and-blend-colors)
- [How to create a pretty README.md file](https://fareskarbia.medium.com/how-to-create-a-pretty-readme-md-file-49d92e298ba2)

## ✍️ Authors <a name = “authors”></a>

Lynx Pardelle

==> ngx-bootstrap-expanded-features-1.4.4.tgz: package/README.md <==
# NgxBootstrapExpandedFeatures

## 📝 Table of Contents

- [About](#about)
- [The problem](#problem)
- [The Solution](#solution)
- [Getting Started](#getting_started)
- [More Information](#more_info)
- [Authors](#authors)

## 🧐 IMPORTANT: BREAKING CHANGES, READ BEFORE UPDATE:</a>
The border changed to borderWidth and bw, please change that in your code to have border well written.

## 🧐 About <a name = “about”></a>

Too many new features for bootstrap made with javascript for better performance and more options without a large css file.

## 😭 The problem <a name = “problem”></a>

Bootstrap doesn't support options of their classes like w-33 to have width: 33%; on an element or things more especific like h-20vh to have an element with: height 20vh;, that can be more efficient and responsive and whenever we need those, we need to get it though a css style sheet and thats not the main point of using Bootstrap.

First I tried to make a library for sass to get to many more options for the classes but there was one problem, it was an 50mb size file after beeing compiled, and we know that 50mb its a large file to be downloaded only to use a few classes that are on the file, but then I get one idea that can let anybody to get all the css that they want without having all the options that they dont use and having the option to create more colors that can be used with bg-newcolorname to get background-color: newcolor; and many more options.

## 😎 The solution <a name = “solution”></a>
We can now use this js library that creates all the css with the classes that are like in bootstrap just in the load of your pages, that mean that your users will only need to download the js and not a css file of 50mb+ and speed up you charge with a simple task that only consumes a few memory of the ram of the user.

## 🏁 Getting Started <a name = “about”></a>

You can check the full tutorial on this [link](https://lynx-bef.vercel.app/)

## ⛏️ More Information <a name = “more_info”></a>

We get the idea of how to use the colors from the sass of bootstrap, more specific, from the _variables.scss file on the source files.

- [How to create a new CSS Rule on an empty css style sheet](https://stackoverflow.com/questions/6620393/is-it-possible-to-alter-a-css-stylesheet-using-javascript-not-the-style-of-an)
- [How to convert HEX to rgb and viceversa](https://stackoverflow.com/questions/5560248/programmatically-lighten-or-darken-a-hex-color-or-rgb-and-blend-colors)
- [How to shadeTintColor](https://stackoverflow.com/questions/5560248/programmatically-lighten-or-darken-a-hex-color-or-rgb-and-blend-colors)
- [How to create a pretty README.md file](https://fareskarbia.medium.com/how-to-create-a-pretty-readme-md-file-49d92e298ba2)

## ✍️ Authors <a name = “authors”></a>

Lynx Pardelle
